# programmershousewrapper
Programmers House api official wrapper: https://www.programmershouse-api.ga
--
Install:
```py
pip install programmershousewrapper
```


# Example of using:
```py
import programmershousewrapper

joke = programmershousewrapper.joke()
print(joke)
​​​​
```


 




# NSFW endpoints using example
```py
import programmershousewrapper

const nsfw = programmershousewrapper.hentai("api key from our discord server: https://discord.gg/gqKbGBWmRz")
```
# NEW endpoints
- alerts - endpoint for air alert notification in Ukraine
```py
import programmershousewrapper

const alerts = programmershousewrapper.alerts()
```
# All endpoints
- joke
- eightball
- cats
- ukraine
- wanted
- wasted
- reddit
- ukrmemes
- reversetext
- emojify
- shotoniphone
- numberfact
- yearsfact
- cosmosfacts
- qrcode
- randomtext
- currentday
- minecraftserver
- aboutinvite
- mars
- geometrydash
- subreddit
- randomanime
- hug
- cry
- dance
- laugh
- kiss
- pat
- wink
- punch
- hentai